# PyCythonizer

## Installation
To install run
```bash
pip install pycythonizer
```

## Usage
To build you project folder run

```bash
pycythonizer /path/to/your/project/ [entry_point] [output_dir]
```
All the arguments are not required. If not given the tool will compile
all python files in the current working directory and output to CWD/build

Happy Coding Enjoy!

